@@ -10,7 +10,7 @@ export AWESOME=/usr/bin/awesome
 export AWESOME_CLIENT=/usr/bin/awesome-client
 export AWESOME_THEMES_PATH=/usr/share/awesome/themes
 export AWESOME_ICON_PATH=/usr/share/awesome/icons
-export RC_FILE=/etc/xdg/awesome/rc.lua
+export AWESOME_RC_FILE=/etc/xdg/awesome/rc.lua
 export CMAKE_BINARY_DIR="$ADTTMP/tests"
 
 # test-gravity needs to be compiled first
